@@ -53,7 +53,7 @@ class DCCA(_DCCA_base):
         :return:
         """
         z = self(*args)
-        return self.objective.loss(*z)
+        return {"objective": self.objective.loss(*z)}
 
     def post_transform(self, z_list, train=False):
         if train:
