@@ -48,4 +48,8 @@ class BarlowTwins(DCCA):
         covariance = torch.sum(
             torch.triu(torch.pow(cross_cov, 2), diagonal=1)
         ) + torch.sum(torch.tril(torch.pow(cross_cov, 2), diagonal=-1))
-        return invariance + covariance
+        return {
+            "objective": invariance + covariance,
+            "invariance": invariance,
+            "covariance": covariance,
+        }
