@@ -113,7 +113,7 @@ class TCCA(_CCA_Base):
         ]
         return self
 
-    def correlations(self, views: Iterable[np.ndarray], y=None, **kwargs):
+    def correlations(self, views: Iterable[np.ndarray], **kwargs):
         """
         Predicts the correlation for the given data using the fit model
 
@@ -136,7 +136,7 @@ class TCCA(_CCA_Base):
         corrs = multiplied_views / norms
         return corrs
 
-    def score(self, views: Iterable[np.ndarray], y=None, **kwargs):
+    def score(self, views: Iterable[np.ndarray], **kwargs):
         """
         Returns the higher order correlations in each dimension
 
@@ -279,7 +279,7 @@ class KTCCA(TCCA):
         ]
         return kernels, self.covs_invsqrt
 
-    def transform(self, views: np.ndarray, y=None, **kwargs):
+    def transform(self, views: np.ndarray, **kwargs):
         """
         Transforms data given a fit k=KCCA model
 
