@@ -11,7 +11,7 @@ import pytorch_lightning as pl
 from torch.utils.data import Subset
 
 # %%
-from cca_zoo.data import Noisy_MNIST_Dataset
+from multiviewdata.torchdatasets import NoisyMNISTDataset
 from cca_zoo.deepmodels import (
     CCALightning,
     get_dataloaders,
@@ -44,7 +44,7 @@ def plot_reconstruction(model, dataloader):
 
 n_train = 500
 n_val = 100
-train_dataset = Noisy_MNIST_Dataset(mnist_type="MNIST", train=True, flatten=True)
+train_dataset = NoisyMNISTDataset(root="",mnist_type="MNIST", train=True, flatten=True, download=True)
 val_dataset = Subset(train_dataset, np.arange(n_train, n_train + n_val))
 train_dataset = Subset(train_dataset, np.arange(n_train))
 train_loader, val_loader = get_dataloaders(train_dataset, val_dataset)
